SystemOrganization addCategory: #OpenCourses!
SystemOrganization addCategory: #'OpenCourses-Tests'!

TestCase subclass: #MaterialManagerTest
	instanceVariableNames: 'emptyMaterialList nonEmptyMaterialList materialManager authorsList submittedFile tags'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses-Tests'!

!MaterialManagerTest methodsFor: 'running' stamp: 'jsa 5/13/2013 19:46'!
setUp
      Data blankData.
	emptyMaterialList := Data materialList copy.
	materialManager := MaterialManager new.
	Session user: (User new email: 'auser@email.com').
	authorsList := OrderedCollection new.
	authorsList add: 'an author1'; add: 'an author2'; add: 'an author3'.
	submittedFile := FakeFile new title: 'a file title'; contents: (ByteArray new).
	tags := SortedCollection new.
	tags add: 'DNA'; add: 'RNA'; add:'Molecular Biology'.
	materialManager submitMaterial: submittedFile title: 'a title' authors: authorsList description: 'a description' type: 'class note' licence: 'GPLv3' tags: tags.
	Session user: (User new email: 'user@email.com').
	authorsList := OrderedCollection new.
	authorsList add: 'author1'; add: 'author2'.
	submittedFile := FakeFile new title: 'file title'; contents: (ByteArray new).
	tags := SortedCollection new.
	tags add: 'OOP'; add: 'Smalltalk'.
	materialManager submitMaterial: submittedFile title: 'title' authors: authorsList description: 'description' type: 'slide show' licence: 'GPLv3' tags: tags.
	nonEmptyMaterialList := Data materialList copy! !

!MaterialManagerTest methodsFor: 'editing' stamp: 'jsa 5/12/2013 18:44'!
testEditMaterialEverythingButTitle
	| newAuthorsList newSubmittedFile newTags |
	Data materialList: nonEmptyMaterialList.
	newAuthorsList := OrderedCollection new add: 'new'; add: 'authors'.
	newSubmittedFile := FakeFile new title: 'new file title'; contents: (ByteArray new).
	newTags := SortedCollection new add: 'new'; add: 'tags'.
	self assert: (materialManager materialList select: [ :material | (material title = 'title'
		and: material description = 'new description'
		and: material authors = newAuthorsList)
		and: material file title = newSubmittedFile title
		and: material tags = newTags
		and: material type = 'code'
		and: material licence = 'GPLv2']) size == 0.
	self assert: (materialManager materialList select: [ :material | material title = 'title' and: material description = 'description']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | materialManager editMaterial: (DidacticMaterial new url: material url; description: 'new description';
			authors: newAuthorsList; file: newSubmittedFile; tags: newTags; type: 'code'; licence: 'GPLv2')].
	self assert: (materialManager materialList select: [ :material | material title = 'title' and: material description = 'description']) size == 0.
		self assert: (materialManager materialList select: [ :material | (material title = 'title'
		and: material description = 'new description'
		and: material authors = newAuthorsList)
		and: material file title = newSubmittedFile title
		and: material tags = newTags
		and: material type = 'code'
		and: material licence = 'GPLv2']) size == 1.! !

!MaterialManagerTest methodsFor: 'editing' stamp: 'jsa 5/13/2013 19:41'!
testEditMaterialLoggedAsAdmin
	UserManager new login: 'admin' password: 'admin'.
	Data materialList: nonEmptyMaterialList.
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | materialManager editMaterial: (DidacticMaterial new url: material url; title: 'new title')].
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 0.
	self assert: (materialManager materialList select: [ :material | material title = 'new title']) size == 1.! !

!MaterialManagerTest methodsFor: 'editing' stamp: 'jsa 5/12/2013 18:56'!
testEditMaterialLoggedAsDifferentUser
	Session user: (User new email: 'another_user@somewhere_over_the_rainbow.com').
	Data materialList: nonEmptyMaterialList.
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | self should: [materialManager editMaterial: (DidacticMaterial new url: material url; title: 'new title')] raise: Error].
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	self assert: (materialManager materialList select: [ :material | material title = 'new title']) size == 0.! !

!MaterialManagerTest methodsFor: 'editing' stamp: 'jsa 5/12/2013 18:33'!
testEditMaterialTitle
	Data materialList: nonEmptyMaterialList.
	self assert: (materialManager materialList select: [ :material | material title = 'new title']) size == 0.
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | materialManager editMaterial: (DidacticMaterial new url: material url; title: 'new title')].
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 0.
	self assert: (materialManager materialList select: [ :material | material title = 'new title' and: material description = 'description']) size == 1.! !

!MaterialManagerTest methodsFor: 'editing' stamp: 'jsa 5/13/2013 14:31'!
testEditMaterialTitleThatDoesntExist
	| numberOfMaterials |
	Data materialList: nonEmptyMaterialList.
	numberOfMaterials := materialManager materialList size.
	self assert: (materialManager materialList select: [ :material | material url = 'inexistent url']) size == 0.
	materialManager editMaterial: (DidacticMaterial new url: 'inexistent url').
	self assert: materialManager materialList size = numberOfMaterials.! !

!MaterialManagerTest methodsFor: 'editing' stamp: 'jsa 5/12/2013 18:52'!
testEditMaterialWithoutLogin
	Data materialList: nonEmptyMaterialList.
	Session user: nil.
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | self should: [materialManager editMaterial: (DidacticMaterial new url: material url; title: 'new title')] raise: Error].
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	self assert: (materialManager materialList select: [ :material | material title = 'new title']) size == 0.! !

!MaterialManagerTest methodsFor: 'removing' stamp: 'jsa 5/12/2013 16:52'!
testRemoveMaterial
	Data materialList: nonEmptyMaterialList.
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | materialManager removeMaterial: material url].
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 0.! !

!MaterialManagerTest methodsFor: 'removing' stamp: 'jsa 5/13/2013 19:48'!
testRemoveMaterialLoggedAsAdmin
	UserManager new login: 'admin' password: 'admin'.
	Data materialList: nonEmptyMaterialList.
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | materialManager removeMaterial: material url].
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 0.! !

!MaterialManagerTest methodsFor: 'removing' stamp: 'jsa 5/12/2013 17:23'!
testRemoveMaterialLoggedAsDifferentUser
	Session user: (User new email: 'another_user@somewhere_over_the_rainbow.com').
	Data materialList: nonEmptyMaterialList.
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | self should: [materialManager removeMaterial: material url] raise: Error].
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.! !

!MaterialManagerTest methodsFor: 'removing' stamp: 'jsa 5/13/2013 14:26'!
testRemoveMaterialThatDoesntExist
	| numberOfMaterials |
	Data materialList: nonEmptyMaterialList.
	numberOfMaterials := materialManager materialList size.
	self assert: (materialManager materialList select: [ :material | material title = 'inexistent title']) size == 0.
	(materialManager materialList select: [ :material | material title = 'inexistent title'])
		do: [ :material | materialManager removeMaterial: material url].
	self assert: materialManager materialList size = numberOfMaterials.! !

!MaterialManagerTest methodsFor: 'removing' stamp: 'jsa 5/12/2013 17:01'!
testRemoveMaterialWithoutLogin
	Session user: nil.
	Data materialList: nonEmptyMaterialList.
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.
	(materialManager materialList select: [ :material | material title = 'title'])
		do: [ :material | self should: [materialManager removeMaterial: material url] raise: Error].
	self assert: (materialManager materialList select: [ :material | material title = 'title']) size == 1.! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/12/2013 23:44'!
testSearchByAuthors
	| searchSpecsNoResult searchSpecsWithResult|
	Data materialList: nonEmptyMaterialList.
	authorsList := OrderedCollection new.
	authorsList add: 'wrong author'.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new authors: authorsList. 
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	authorsList add: 'author1'.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new authors: authorsList. 
	self assert: (materialManager search: searchSpecsWithResult) size == 1.
	authorsList add: 'author2'.
	self assert: (materialManager search: searchSpecsWithResult) size == 1.
	authorsList add: 'an author3'.
	self assert: (materialManager search: searchSpecsWithResult) size == 2.
	! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/12/2013 18:42'!
testSearchByCreationDate
	| searchSpecsNoResult searchSpecsWithResult |
	nonEmptyMaterialList := Data materialList copy.
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new creationDateStart: (TimeStamp now plusSeconds: 4); creationDateEnd: (TimeStamp now plusSeconds: 10).
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new creationDateStart: (TimeStamp now minusSeconds: 14); creationDateEnd: (TimeStamp now plusSeconds: 10).
	self assert: (materialManager search: searchSpecsWithResult) size == 2.! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/12/2013 22:46'!
testSearchByDescription
	| searchSpecsNoResult searchSpecsWithResult |
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new description:  'wrong description'.
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new description: 'description'.
	self assert: (materialManager search: searchSpecsWithResult) size == 1.! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/12/2013 22:01'!
testSearchByLastUploadDate
	| searchSpecsNoResult searchSpecsWithResult |
	nonEmptyMaterialList := Data materialList copy.
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new lastUploadDateStart: (TimeStamp now plusSeconds: 4); lastUploadDateEnd: (TimeStamp now plusSeconds: 10).
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new lastUploadDateStart: (TimeStamp now minusSeconds: 14); lastUploadDateEnd: (TimeStamp now plusSeconds: 10).
	self assert: (materialManager search: searchSpecsWithResult) size == 2.! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/12/2013 22:56'!
testSearchByLicence
	| searchSpecsNoResult searchSpecsWithResult |
	nonEmptyMaterialList add: (DidacticMaterial new licence: 'none').
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new licence:  'wrong licence'.
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new licence: 'none'.
	self assert: (materialManager search: searchSpecsWithResult) size == 1.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new licence: 'GPLv3'.
	self assert: (materialManager search: searchSpecsWithResult) size == 2.
	
	! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/12/2013 22:08'!
testSearchByOwner
	| searchSpecsNoResult searchSpecsWithResult |
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new owner:  'wrong_owner@email.com'.
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new owner: 'user@email.com'.
	self assert: (materialManager search: searchSpecsWithResult) size == 1.! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/12/2013 23:45'!
testSearchByTags
	| searchSpecsNoResult searchSpecsWithResult|
	Data materialList: nonEmptyMaterialList.
	tags := SortedCollection new.
	authorsList add: 'wrong tag'.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new tags: tags. 
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	tags := OrderedCollection new. 
	tags add: 'OOP'.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new tags: tags. 
	self assert: (materialManager search: searchSpecsWithResult) size == 1.
	authorsList add: 'Smalltalk'.
      searchSpecsWithResult := DidacticMaterialSearchSpecs new tags: tags.
	self assert: (materialManager search: searchSpecsWithResult) size == 1.
	tags add: 'DNA'.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new tags: tags.
	self assert: (materialManager search: searchSpecsWithResult) size == 2.
	! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'jsa 5/11/2013 19:34'!
testSearchByTitle
	| searchSpecsNoResult searchSpecsWithResult |
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new title: 'wrong title'.
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new title: 'title'.
	self assert: (materialManager search: searchSpecsWithResult) size == 1.! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'jsa 5/11/2013 19:43'!
testSearchByTitleAndCreationDate
	| searchSpecsNoResult searchSpecsWithResult |
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new title: 'title'; creationDateStart: (TimeStamp now plusSeconds: 4); creationDateEnd: (TimeStamp now plusSeconds: 10).
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new title: 'title'; creationDateStart: (TimeStamp now minusSeconds: 14); creationDateEnd: (TimeStamp now plusSeconds: 10).
	self assert: (materialManager search: searchSpecsWithResult) size == 1.! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/12/2013 18:19'!
testSearchByTitleAndLastUploadDate
	| searchSpecsNoResult searchSpecsWithResult |
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new title: 'title'; lastUploadDateStart: (TimeStamp now plusSeconds: 4); lastUploadDateEnd: (TimeStamp now plusSeconds: 10).
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new title: 'title'; lastUploadDateStart: (TimeStamp now minusSeconds: 14); lastUploadDateEnd: (TimeStamp now plusSeconds: 10).
	self assert: (materialManager search: searchSpecsWithResult) size == 1.! !

!MaterialManagerTest methodsFor: 'searching' stamp: 'Su 5/13/2013 00:04'!
testSearchByType
	| searchSpecsNoResult searchSpecsWithResult |
	Data materialList: nonEmptyMaterialList.
	searchSpecsNoResult := DidacticMaterialSearchSpecs new type: 'wrong type'.
	self assert: (materialManager search: searchSpecsNoResult) size == 0.
	searchSpecsWithResult := DidacticMaterialSearchSpecs new type: 'slide show'.
	self assert: (materialManager search: searchSpecsWithResult) size == 1.! !

!MaterialManagerTest methodsFor: 'submitting' stamp: 'Su 5/12/2013 21:40'!
testSubmitMaterial
	Data materialList: emptyMaterialList.
	materialManager submitMaterial: submittedFile title: 'title' authors: authorsList description: 'description' type: 'slide show' licence: 'GPLv3' tags: tags.
	self assert: (materialManager materialList select: [:material | material title = 'title']) size == 1.! !

!MaterialManagerTest methodsFor: 'submitting' stamp: 'Su 5/12/2013 22:00'!
testSubmitMaterialAutomaticFields
	| loggedUser now maxDuration|
	Data materialList: emptyMaterialList.
	loggedUser := User new email: 'user@email.com'.
	Session user: loggedUser.
	maxDuration := Duration seconds: 1.
	now := TimeStamp now.
	materialManager submitMaterial: submittedFile title: 'title' authors: authorsList description: 'description' type: 'slide show' licence: 'GPLv3' tags: tags.
	self assert: (materialManager materialList select: [:material | material owner = loggedUser and: material creationDate - now <  maxDuration and: material lastUploadDate - now < maxDuration]) size == 1.
	self assert: (materialManager materialList select: [:material | material url = 'user@email.com/title']) size == 1! !

!MaterialManagerTest methodsFor: 'submitting' stamp: 'jsa 5/11/2013 18:37'!
testSubmitMaterialWithoutLogin
	Data materialList: emptyMaterialList.
	Session user: nil.
	self should: [materialManager submitMaterial: submittedFile title: 'title' authors: authorsList description: 'description' type: 'slide show' licence: 'GPLv3' tags: tags] raise: Error.
	self assert: (materialManager materialList select: [:material | material title = 'title']) size == 0.! !

TestCase subclass: #UserManagerTest
	instanceVariableNames: 'emptyUserList nonEmptyUserList userManager'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses-Tests'!

!UserManagerTest methodsFor: 'running' stamp: 'Su 5/13/2013 17:08'!
setUp
	Data blankData.
	emptyUserList := Data userList copy.
	userManager := UserManager new.
	userManager registerNewUser: 'john' password: '123admin' email: 'johnadmin@me.com'.
	nonEmptyUserList := Data userList copy.
	userManager login: 'johnadmin@me.com' password: '123admin'.
	Data admin: nil.
	! !

!UserManagerTest methodsFor: 'testing' stamp: 'Su 5/13/2013 17:33'!
testChangeEmail
	| mockUser |
	"Deveria dar erro quando email j est cadastrado"
	self should: [userManager changeEmail: Session user newEmail:  Session user email] raise: Error.
	mockUser := Session user copy.
	userManager changeEmail: Session user newEmail: 'johnadmin@newemail.com'.
	self assert: [Session user email = 'johnadmin@newemail.com'].
	self assert: [Data userList includes: Session user].
	self shouldnt: [Data userList includes: mockUser]! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/13/2013 19:19'!
testChangeEmailLoggedAsAdmin
	| oldUser user |
	oldUser := Session user copy.
	user := Session user.
	userManager login: 'admin' password: 'admin'.
	"Deveria dar erro quando email j est cadastrado"
	self should: [userManager changeEmail: user newEmail:  user email] raise: Error.
	userManager changeEmail: user newEmail: 'johnadmin@newemail.com'.
	self assert: [Session user email = 'admin'].
	self assert: [Data userList includes: (User new email: 'johnadmin@newemail.com')].
	self shouldnt: [Data userList includes: oldUser].
! !

!UserManagerTest methodsFor: 'testing' stamp: 'Su 5/13/2013 17:46'!
testChangeEmailWithoutLogin
	| oldUser |
	oldUser := Session user.
	Session user: nil.
	self should: [userManager changeEmail:  oldUser newEmail: 'blabla'] raise: Error
! !

!UserManagerTest methodsFor: 'testing' stamp: 'Su 5/13/2013 17:35'!
testChangeEmailWithoutPermission
	| oldUser |
	oldUser := Session user.
	Session user: (User new email: 'another_user@email.com').
	self should: [userManager changeEmail:  oldUser newEmail: 'blabla'] raise: Error
! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/13/2013 17:40'!
testChangeName
	| newName |
	newName := 'new_name'.
	userManager changeName: Session user newName: newName.
	self assert: [Session user name = newName].
	self assert: [Data userList includes: Session user]! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/13/2013 19:17'!
testChangeNameLoggedAsAdmin
	| user newName |
	user := Session user copy.
	userManager login: 'admin' password: 'admin'.
	newName := 'new_name'.
	userManager changeName: user newName: newName.
	self assert: [Session user email = 'admin'].
	self assert: [Data userList includes: user].
	self assert: [(Data userList select: [ :anUser | anUser = user and: anUser name = newName]) size = 1].! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/13/2013 17:56'!
testChangeNameWithoutPermission
	| oldUser |
	oldUser := Session user.
	Session user: (User new email: 'another_user@email.com').
	self should: [userManager changeName: oldUser newName: 'blabla'] raise: Error! !

!UserManagerTest methodsFor: 'testing' stamp: 'Su 5/13/2013 17:21'!
testChangePassword
	| newPassword |
	newPassword := 'new_password'.
	userManager changePassword: Session user newPassword: newPassword.
	self assert: [Session user password = newPassword].
	self assert: [Data userList includes: Session user]
! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/13/2013 19:17'!
testChangePasswordLoggedAsAdmin
	| newPassword oldUser|
	newPassword := 'new_password'.
	oldUser := Session user.
      userManager login: 'admin' password:'admin'.
	userManager changePassword: oldUser newPassword: newPassword.
	self assert: [Session user email = 'admin'].
	self assert: [oldUser password = newPassword].
	self assert: [Data userList includes: oldUser]
! !

!UserManagerTest methodsFor: 'testing' stamp: 'Su 5/13/2013 17:56'!
testChangePasswordWithoutLogin
	| oldUser |
	oldUser := Session user.
	Session user: nil.
	self should: [userManager changePassword:  oldUser newPassword: 'new_password'] raise: Error.
	self assert: Session user isNil
! !

!UserManagerTest methodsFor: 'testing' stamp: 'Su 5/13/2013 17:57'!
testChangePasswordWithoutPermission
	| oldUser |
	oldUser := Session user.
	Session user: (User new email: 'another_user@email.com').
	self should: [userManager changePassword:  oldUser newPassword: 'new_password'] raise: Error.
	self assert: (Session user email = 'another_user@email.com')
! !

!UserManagerTest methodsFor: 'testing' stamp: 'Su 5/13/2013 17:08'!
testFirstAdminLogin
	Data userList: emptyUserList.
	Data admin: nil.
	Session user: nil.
	self
		should: [userManager login: 'admin' password: 'admin'.
			Session user = Data admin and: (Data admin isNil) not 
			and: (userManager userList includes: (User new email: 'admin'))].
	Session user: nil.
	self
		should: [userManager login: 'admin' password: 'admin'.
			Session user = Data admin and: (Data admin isNil) not 
			and: (userManager userList includes: (User new email: 'admin'))]! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/11/2013 18:30'!
testLogin
	| loggedUser |
	Data userList: nonEmptyUserList.
	self
		should: [userManager login: 'emailDoesntExist' password: '123admin']
		raise: Error.
	self
		should: [userManager login: 'johnadmin@me.com' password: 'wrongPassword']
		raise: Error.
	loggedUser := User new email: 'johnadmin@me.com'.
	self
		should: [userManager login: 'johnadmin@me.com' password: '123admin'.
			Session user = loggedUser]! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/13/2013 19:31'!
testLogoff
	(Session user == nil)
		ifFalse: [
			userManager logoff.
			self assert: [Session user == nil]
			].! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/11/2013 18:31'!
testRegisterNewUser
	| createdUser |
	createdUser := User new name: 'john';
				 password: '123admin';
				 email: 'johnadmin@me.com'.
	Data userList: emptyUserList.
	self
		shouldnt: [userManager hasUser: createdUser].
	userManager
		registerNewUser: 'john'
		password: '123admin'
		email: 'johnadmin@me.com'.
	self
		assert: (userManager hasUser: createdUser)! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/13/2013 19:33'!
testRemoveUser
	| listSize currentUser|
	currentUser := Session user.
	
	"try to remove an unexistent user"
	self should: [userManager removeUser: (User new email: 'wrong@email.com')] raise: Error.
	
	"try to remove unlogged"
	Session user: nil.
	self should: [userManager removeUser: currentUser] raise: Error.
	
	"try to remove correct"
	Session user: currentUser.
	listSize := Data userList size.
	userManager removeUser: currentUser.
	self assert: [listSize > Data userList size].
	! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/13/2013 19:35'!
testRemoveUserLoggedAsAdmin
	| listSize currentUser|
	currentUser := Session user.
	userManager login: 'admin' password:'admin'.
	listSize := Data userList size.
	userManager removeUser: currentUser.
	self assert: [listSize > Data userList size].
	self assert: [Session user email = 'admin'].
	! !

!UserManagerTest methodsFor: 'testing' stamp: 'jsa 5/11/2013 18:31'!
testTryToRegisterAnAlreadyRegisteredUser
	Data userList: nonEmptyUserList.
	self
		should: [userManager
				registerNewUser: 'jon'
				password: '123admin321'
				email: 'johnadmin@me.com']
		raise: Error! !

Object subclass: #Data
	instanceVariableNames: ''
	classVariableNames: 'Admin MaterialList UserList'
	poolDictionaries: ''
	category: 'OpenCourses'!

!Data class methodsFor: 'accessing' stamp: 'Su 5/13/2013 15:41'!
admin
	^Admin! !

!Data class methodsFor: 'accessing' stamp: 'Su 5/13/2013 15:41'!
admin: aUser
	Admin := aUser! !

!Data class methodsFor: 'accessing' stamp: 'jsa 5/13/2013 19:50'!
blankData
	UserList := Set new.
	MaterialList := Set new.
	Admin := nil.! !

!Data class methodsFor: 'accessing' stamp: 'jsa 5/11/2013 18:19'!
materialList
	^ MaterialList! !

!Data class methodsFor: 'accessing' stamp: 'jsa 5/11/2013 18:19'!
materialList: aMaterialList
	MaterialList := aMaterialList! !

!Data class methodsFor: 'accessing' stamp: 'jsa 5/11/2013 18:19'!
userList
	^ UserList! !

!Data class methodsFor: 'accessing' stamp: 'jsa 5/11/2013 18:19'!
userList: aUserList
	UserList := aUserList! !

Object subclass: #DidacticMaterial
	instanceVariableNames: 'file url title description authors owner licence creationDate lastUploadDate type tags'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

!DidacticMaterial methodsFor: 'comparing' stamp: 'jsa 5/12/2013 16:57'!
= aDidacticMaterial
	aDidacticMaterial ifNotNil: [^ aDidacticMaterial url = self url].
	^ false! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
authors
	"Answer the value of authors"

	^ authors! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
authors: anObject
	"Set the value of authors"

	authors := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
creationDate
	"Answer the value of creationDate"

	^ creationDate! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
creationDate: anObject
	"Set the value of creationDate"

	creationDate := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:13'!
description
	"Answer the value of description"

	^ description! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:13'!
description: anObject
	"Set the value of description"

	description := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
file
	"Answer the value of file"

	^ file! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
file: anObject
	"Set the value of file"

	file := anObject! !

!DidacticMaterial methodsFor: 'comparing' stamp: 'jsa 5/12/2013 16:58'!
hash
	^ self url hash! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
lastUploadDate
	"Answer the value of lastUploadDate"

	^ lastUploadDate! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
lastUploadDate: anObject
	"Set the value of lastUploadDate"

	lastUploadDate := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
licence
	"Answer the value of licence"

	^ licence! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
licence: anObject
	"Set the value of licence"

	licence := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
owner
	"Answer the value of owner"

	^ owner! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
owner: anObject
	"Set the value of owner"

	owner := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
tags
	"Answer the value of tags"

	^ tags! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
tags: anObject
	"Set the value of tags"

	tags := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
title
	"Answer the value of title"

	^ title! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
title: anObject
	"Set the value of title"

	title := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
type
	"Answer the value of type"

	^ type! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/11/2013 17:12'!
type: anObject
	"Set the value of type"

	type := anObject! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/12/2013 16:40'!
url
	"Answer the value of url"

	^ url! !

!DidacticMaterial methodsFor: 'accessing' stamp: 'jsa 5/12/2013 16:40'!
url: anObject
	"Set the value of url"

	url := anObject! !

Object subclass: #DidacticMaterialSearchSpecs
	instanceVariableNames: 'title description authors owner licence creationDateStart creationDateEnd lastUploadDateStart lastUploadDateEnd type tags'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
authors
	"Answer the value of authors"

	^ authors! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
authors: anObject
	"Set the value of authors"

	authors := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
creationDateEnd
	"Answer the value of creationDateEnd"

	^ creationDateEnd! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
creationDateEnd: anObject
	"Set the value of creationDateEnd"

	creationDateEnd := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
creationDateStart
	"Answer the value of creationDateStart"

	^ creationDateStart! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
creationDateStart: anObject
	"Set the value of creationDateStart"

	creationDateStart := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
description
	"Answer the value of description"

	^ description! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
description: anObject
	"Set the value of description"

	description := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
lastUploadDateEnd
	"Answer the value of lastUploadDateEnd"

	^ lastUploadDateEnd! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
lastUploadDateEnd: anObject
	"Set the value of lastUploadDateEnd"

	lastUploadDateEnd := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
lastUploadDateStart
	"Answer the value of lastUploadDateStart"

	^ lastUploadDateStart! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
lastUploadDateStart: anObject
	"Set the value of lastUploadDateStart"

	lastUploadDateStart := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
licence
	"Answer the value of licence"

	^ licence! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
licence: anObject
	"Set the value of licence"

	licence := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'comparing' stamp: 'Su 5/12/2013 23:31'!
matches: aDidacticMaterial
	self title ifNotNil: [aDidacticMaterial title = self title ifFalse: [^ false]].
	self creationDateStart ifNotNil: [aDidacticMaterial creationDate > self creationDateStart ifFalse: [^ false]].
	self creationDateEnd ifNotNil: [aDidacticMaterial creationDate < self creationDateEnd ifFalse: [^ false]].
	self lastUploadDateStart ifNotNil: [aDidacticMaterial lastUploadDate > self lastUploadDateStart ifFalse: [^ false]].
	self lastUploadDateEnd ifNotNil: [aDidacticMaterial lastUploadDate < self lastUploadDateEnd ifFalse: [^ false]].
	self description ifNotNil: [aDidacticMaterial description = self description ifFalse: [^ false]].
	self owner ifNotNil: [aDidacticMaterial owner email = self owner ifFalse: [^ false]].
	self authors ifNotNil: [((aDidacticMaterial authors) includesAnyOf: (self authors)) ifFalse: [^ false]].
	self licence ifNotNil: [aDidacticMaterial licence = self licence ifFalse: [^false]].
	self type ifNotNil: [aDidacticMaterial type = self type ifFalse: [^ false]].
	self tags ifNotNil: [ ((aDidacticMaterial tags) includesAnyOf: (self tags)) ifFalse: [^ false]].
	^true! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
owner
	"Answer the value of owner"

	^ owner! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
owner: anObject
	"Set the value of owner"

	owner := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
tags
	"Answer the value of tags"

	^ tags! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
tags: anObject
	"Set the value of tags"

	tags := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
title
	"Answer the value of title"

	^ title! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
title: anObject
	"Set the value of title"

	title := anObject! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
type
	"Answer the value of type"

	^ type! !

!DidacticMaterialSearchSpecs methodsFor: 'accessing' stamp: 'jsa 5/11/2013 19:34'!
type: anObject
	"Set the value of type"

	type := anObject! !

Object subclass: #FakeFile
	instanceVariableNames: 'title contents'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

!FakeFile methodsFor: 'accessing' stamp: 'jsa 5/11/2013 16:50'!
contents
	"Answer the value of contents"

	^ contents! !

!FakeFile methodsFor: 'accessing' stamp: 'jsa 5/11/2013 16:50'!
contents: anObject
	"Set the value of contents"

	contents := anObject! !

!FakeFile methodsFor: 'accessing' stamp: 'jsa 5/11/2013 16:50'!
title
	"Answer the value of title"

	^ title! !

!FakeFile methodsFor: 'accessing' stamp: 'jsa 5/11/2013 16:50'!
title: anObject
	"Set the value of title"

	title := anObject! !

Object subclass: #MaterialManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

!MaterialManager methodsFor: 'private' stamp: 'Su 5/12/2013 21:55'!
createMaterialURL: aMaterial
	| numberOfMaterialsWithSameAuthorAndTitle|
	 numberOfMaterialsWithSameAuthorAndTitle := (Data materialList select: [ : material | material owner = aMaterial owner and: material title = aMaterial title]) size.
	^aMaterial owner email, '/', aMaterial title, ((numberOfMaterialsWithSameAuthorAndTitle = 0) ifTrue:[''] ifFalse:['_', numberOfMaterialsWithSameAuthorAndTitle]).
	! !

!MaterialManager methodsFor: 'management' stamp: 'jsa 5/13/2013 15:18'!
editMaterial: anEditedMaterial
	| materialToEdit |
	materialToEdit := Data materialList like: anEditedMaterial.
	materialToEdit ifNotNil: [
		(UserManager new canEditMaterial: materialToEdit owner)
			ifFalse: [Error signal: 'User doesn''t have permission to edit this material'].
	
		anEditedMaterial title ifNotNil: [materialToEdit title: anEditedMaterial title].
		anEditedMaterial description ifNotNil: [materialToEdit description: anEditedMaterial description].
		anEditedMaterial authors ifNotNil: [materialToEdit authors: anEditedMaterial authors].
		anEditedMaterial file ifNotNil: [materialToEdit file: anEditedMaterial file].
		anEditedMaterial tags ifNotNil: [materialToEdit tags: anEditedMaterial tags].
		anEditedMaterial type ifNotNil: [materialToEdit type: anEditedMaterial type].
		anEditedMaterial licence ifNotNil: [materialToEdit licence: anEditedMaterial licence].
	]! !

!MaterialManager methodsFor: 'private' stamp: 'jsa 5/11/2013 18:21'!
materialList
	^ Data materialList! !

!MaterialManager methodsFor: 'management' stamp: 'jsa 5/13/2013 15:14'!
removeMaterial: aUrl
	| materialToRemove |
	materialToRemove := Data materialList like: (DidacticMaterial new url: aUrl).
	(UserManager new canRemoveMaterial: materialToRemove owner)
		ifFalse: [Error signal: 'User doesn''t have permission to remove this material'].
	Data materialList remove: materialToRemove.! !

!MaterialManager methodsFor: 'searching' stamp: 'jsa 5/11/2013 19:35'!
search: aDidacticMaterialSearchSpecs
	^ Data materialList select: [ :material | aDidacticMaterialSearchSpecs matches: material]! !

!MaterialManager methodsFor: 'management' stamp: 'Su 5/12/2013 21:42'!
submitMaterial: submittedFile title: title authors: authorsList description: description type: type licence: licence tags: tags
	| material now user|
	now := TimeStamp now.
	user := Session user.
	UserManager new canSubmitMaterial ifTrue: [
	material := DidacticMaterial new file: submittedFile; title: title; authors: authorsList; description: description; type: type; licence: licence; tags: tags; creationDate: now; lastUploadDate: now; owner: user.
	material url: (self createMaterialURL: material).
	Data materialList add: material]
	ifFalse: [Error signal: 'User doesn''t have permission to submit material']! !

Object subclass: #Session
	instanceVariableNames: ''
	classVariableNames: 'CurrentUser'
	poolDictionaries: ''
	category: 'OpenCourses'!

!Session class methodsFor: 'accessing' stamp: 'cmb 5/10/2013 18:58'!
user
	^CurrentUser! !

!Session class methodsFor: 'accessing' stamp: 'cmb 5/10/2013 18:58'!
user: aUser
	CurrentUser := aUser! !

Object subclass: #User
	instanceVariableNames: 'name password email'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

!User commentStamp: 'RFG 5/2/2013 11:22' prior: 0!
Represents a user in the system.!

!User class methodsFor: 'instance creation' stamp: 'RicardoGuimaraes 6/28/2013 20:48'!
newNamed: aName
	"comment stating purpose of message"
	
	|newUser
	 sys	   |
		
	newUser := self new.
	newUser name: aName.
	newUser groupList isNil
		ifTrue: [newUser groupList: OrderedCollection new].
	newUser courseList isNil
		ifTrue: [newUser courseList: OrderedCollection new].
	newUser contentList isNil
		ifTrue: [newUser contentList: OrderedCollection new].
		
	sys := System create.
	newUser id: sys nextUserId.
	sys addUser: newUser.
	^newUser! !

!User class methodsFor: 'instance creation' stamp: 'RicardoGuimaraes 6/29/2013 09:53'!
newNamed: aName withId: anUserId
	"comment stating purpose of message"
	
	|newUser
	 sys	   |
		
	newUser := self new.
	newUser name: aName.
	newUser groupList isNil
		ifTrue: [newUser groupList: OrderedCollection new].
	newUser courseList isNil
		ifTrue: [newUser courseList: OrderedCollection new].
	newUser contentList isNil
		ifTrue: [newUser contentList: OrderedCollection new].
		
	sys := System create.
	newUser id: anUserId.
	sys addUser: newUser.
	^newUser! !

!User methodsFor: 'comparing' stamp: 'Su 5/13/2013 17:11'!
= aUser 
	aUser ifNotNil: [^ self email = aUser email].
	^false! !

!User methodsFor: 'accessing' stamp: 'RFG 5/3/2013 16:31'!
contentList
	"Returns a list with the IDs of the Contents owned by the user."

	^contentList.! !

!User methodsFor: 'accessing' stamp: 'RFG 5/3/2013 18:15'!
contentList: anOrderedCollection
	"Sets the user content list."

	contentList := anOrderedCollection.! !

!User methodsFor: 'accessing' stamp: 'RFG 5/3/2013 16:39'!
courseList
	"comment stating purpose of message"

	^courseList.! !

!User methodsFor: 'accessing' stamp: 'RFG 5/3/2013 18:19'!
courseList: anOrderedCollection
	"Sets the user content list."

	courseList := anOrderedCollection.! !

!User methodsFor: 'deletion' stamp: 'AP 6/9/2013 15:58'!
delete
	
	| sys |
	sys := SystemFacade new.
	sys deleteUser: self.! !

!User methodsFor: 'remotion' stamp: 'RicardoGuimaraes 6/29/2013 11:04'!
delete: aDidaticStructure
	"Tries to delete a structure."

	| able |
	able := aDidaticStructure ownerList includes: self.
	able
		ifTrue:[aDidaticStructure delete.]
		ifFalse: [^Exception.].
	! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:30'!
email
	"Answer the value of email"

	^ email! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:30'!
email: anObject
	"Set the value of email"

	email := anObject! !

!User methodsFor: 'subscription' stamp: 'AP 6/9/2013 16:01'!
enrollCourse: courseId

	| sys |
	
	sys := SystemFacade new.
	sys  enrollUser: self atCourse: courseId.
	courseList add: courseId.! !

!User methodsFor: 'subscription' stamp: 'AP 6/9/2013 16:13'!
enterGroup: aGroupId
	"Makes the user part of the group with the given ID."
	
	| sys |
	sys := SystemFacade new.
	sys enrollUser: self atGroup: aGroupId.
	groupList add: aGroupId.! !

!User methodsFor: 'accessing' stamp: 'RFG 5/3/2013 16:30'!
groupList
	"Returns a list with the IDs of the Groups which the user is in."

	^groupList.! !

!User methodsFor: 'accessing' stamp: 'RFG 5/3/2013 18:16'!
groupList: anOrderedCollection
	"Sets the user group list."

	groupList := anOrderedCollection.! !

!User methodsFor: 'comparing' stamp: 'cmb 5/10/2013 17:33'!
hash
	^ email hash! !

!User methodsFor: 'accessing' stamp: 'RFG 5/13/2013 13:00'!
id
	"Returns the user ID."

	^id.! !

!User methodsFor: 'accessing' stamp: 'RFG 5/13/2013 13:01'!
id: anId
	"comment stating purpose of message"

	id := anId.! !

!User methodsFor: 'accessing' stamp: 'cmb 5/13/2013 00:25'!
initialize
	super initialize.
	self email: ''.
	self name: ''.
	self password: ''.! !

!User methodsFor: 'checking' stamp: 'cmb 5/13/2013 00:13'!
isLogged
	^ Session user = self.! !

!User methodsFor: 'subscription' stamp: 'AP 6/9/2013 15:59'!
leaveGroup: aGroupId

	| sys |
	
	sys := SystemFacade new.
	sys removeUser: self fromGroup: aGroupId.
	groupList remove: aGroupId.! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:34'!
name
	"Answer the value of name"
	^ name! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:31'!
name: anObject
	"Set the value of name"

	name := anObject! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:30'!
password
	"Answer the value of password"

	^ password! !

!User methodsFor: 'accessing' stamp: 'cmb 5/10/2013 16:30'!
password: anObject
	"Set the value of password"

	password := anObject! !

!User methodsFor: 'subscription' stamp: 'AP 6/9/2013 16:03'!
watchLecture: aLectureId

	| sys |
	
	sys := SystemFacade new.
	sys makeUser: self watchLecture: aLectureId.
! !

!User methodsFor: 'subscription' stamp: 'RicardoGuimaraes 6/28/2013 11:10'!
withdrawCourse: aCourse

	| sys |
	
	sys := SystemFacade new.
	sys removeUser: self fromCourse: aCourse.
	courseList remove: aCourse.! !

Object subclass: #UserManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OpenCourses'!

!UserManager methodsFor: 'permission' stamp: 'Su 5/13/2013 16:48'!
canChangeUserEmail: anUser
	Session user ifNotNil:
		[^ (Session user = anUser) or: (Session user = Data admin)].
	^ false
	! !

!UserManager methodsFor: 'permission' stamp: 'jsa 5/13/2013 17:51'!
canChangeUserName: anUser
	Session user ifNotNil:
		[^ (Session user = anUser) or: (Session user = Data admin)].
	^ false
	! !

!UserManager methodsFor: 'permission' stamp: 'Su 5/13/2013 17:44'!
canChangeUserPassword: anUser
	Session user ifNotNil:
		[^ (Session user = anUser) or: (Session user = Data admin)].
	^ false
	! !

!UserManager methodsFor: 'permission' stamp: 'Su 5/13/2013 16:24'!
canEditMaterial: userOwner
	Session user ifNotNil:
		[^ (Session user = userOwner) or: (Session user = Data admin)].
	^ false
	! !

!UserManager methodsFor: 'permission' stamp: 'Su 5/13/2013 16:24'!
canRemoveMaterial: userOwner
	Session user ifNotNil:
		[^ Session user = userOwner or: (Session user = Data admin)].
	^ false
	! !

!UserManager methodsFor: 'permission' stamp: 'jsa 5/13/2013 19:25'!
canRemoveUser: userToRemove
	Session user ifNotNil:
		[^ Session user = userToRemove or: (Session user = Data admin)].
	^ false
	! !

!UserManager methodsFor: 'permission' stamp: 'jsa 5/11/2013 18:44'!
canSubmitMaterial
	^ (Session user isNil) not! !

!UserManager methodsFor: 'editing' stamp: 'Su 5/13/2013 17:28'!
changeEmail: user newEmail: newEmail
	(Data userList includes: (User new email: newEmail))
		ifTrue: [Error signal: 'email already used by another user.']
		ifFalse: [
			(self canChangeUserEmail: user) ifTrue: [
				self registerNewUser: user name password: user password email: newEmail.
				Data userList remove: user.
				(Session user = user) ifTrue: [
				Session user: (Data userList like: (User new email: newEmail)).
				]] ifFalse: [Error signal: 'User doesn''t have permission to change this email.']]
		


! !

!UserManager methodsFor: 'editing' stamp: 'jsa 5/13/2013 17:51'!
changeName: anUser newName: newName
	| registeredUser |
	(self canChangeUserName: anUser) ifTrue: [
		registeredUser := Data userList like: anUser.
		registeredUser name: newName.
	] ifFalse: [
		Error signal: 'User doesn''t have permission to change this name.'
	]
		! !

!UserManager methodsFor: 'editing' stamp: 'Su 5/13/2013 17:44'!
changePassword: anUser newPassword: newPassword
	(self canChangeUserPassword: anUser) ifTrue: [
		anUser password: newPassword.
		] 
	ifFalse: [
		Error signal: 'User doesn''t have permission to change this password.'
		]
		! !

!UserManager methodsFor: 'private' stamp: 'jsa 5/11/2013 18:21'!
hasUser: aUser 
	^ Data userList includes: aUser! !

!UserManager methodsFor: 'authentication' stamp: 'Su 5/13/2013 16:19'!
login: email password: password 
	| user registeredUser | 
	Data admin ifNil: [(email = 'admin' and: password = 'admin') ifTrue: [self registerDefaultAdmin]].
	user := User new email: email;
				 password: password.
	registeredUser := Data userList
				like: user
				ifAbsent: [Error signal: 'User/Password incorrect!!'].
	user password = registeredUser password
		ifTrue: [Session user: registeredUser]
		ifFalse: [Error signal: 'User/Password incorrect!!']! !

!UserManager methodsFor: 'authentication' stamp: 'cmb 5/13/2013 19:22'!
logoff
	Session user: nil.! !

!UserManager methodsFor: 'managing' stamp: 'jsa 5/13/2013 19:49'!
registerDefaultAdmin
	self registerNewUser: 'admin' password: 'admin' email: 'admin'.
	Data admin: (Data userList like: (User new email: 'admin')). ! !

!UserManager methodsFor: 'managing' stamp: 'jsa 5/11/2013 18:22'!
registerNewUser: name password: password email: email 
	| newUser |
	newUser := User new name: name;
				 password: password;
				 email: email.
	(Data userList includes: newUser)
		ifFalse: [Data userList add: newUser]
		ifTrue: [Error signal: 'Duplicated user']! !

!UserManager methodsFor: 'managing' stamp: 'jsa 5/13/2013 19:26'!
removeUser: anUser
	| userToRemove |
	userToRemove := Data userList like: anUser.
	(UserManager new canRemoveUser: userToRemove)
		ifFalse: [Error signal: 'User doesn''t have permission to remove this user'].
	Data userList remove: userToRemove.
	(Session user = anUser) ifTrue: [
		self logoff
	]! !

!UserManager methodsFor: 'private' stamp: 'Su 5/13/2013 16:21'!
userList
	"Answer the value of userList"

	^Data userList! !
